/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: ssc-sensor-suid.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "ssc-sensor-suid.pb-c.h"
void   ssc_suid_request__init
                     (SscSuidRequest         *message)
{
  static const SscSuidRequest init_value = SSC_SUID_REQUEST__INIT;
  *message = init_value;
}
size_t ssc_suid_request__get_packed_size
                     (const SscSuidRequest *message)
{
  assert(message->base.descriptor == &ssc_suid_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_suid_request__pack
                     (const SscSuidRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_suid_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_suid_request__pack_to_buffer
                     (const SscSuidRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_suid_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscSuidRequest *
       ssc_suid_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscSuidRequest *)
     protobuf_c_message_unpack (&ssc_suid_request__descriptor,
                                allocator, len, data);
}
void   ssc_suid_request__free_unpacked
                     (SscSuidRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_suid_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_suid_response__init
                     (SscSuidResponse         *message)
{
  static const SscSuidResponse init_value = SSC_SUID_RESPONSE__INIT;
  *message = init_value;
}
size_t ssc_suid_response__get_packed_size
                     (const SscSuidResponse *message)
{
  assert(message->base.descriptor == &ssc_suid_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_suid_response__pack
                     (const SscSuidResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_suid_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_suid_response__pack_to_buffer
                     (const SscSuidResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_suid_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscSuidResponse *
       ssc_suid_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscSuidResponse *)
     protobuf_c_message_unpack (&ssc_suid_response__descriptor,
                                allocator, len, data);
}
void   ssc_suid_response__free_unpacked
                     (SscSuidResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_suid_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor ssc_suid_request__field_descriptors[3] =
{
  {
    "data_type",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(SscSuidRequest, data_type),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "enable_updates",
    2,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_BOOL,
    offsetof(SscSuidRequest, has_enable_updates),
    offsetof(SscSuidRequest, enable_updates),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "only_default_values",
    3,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_BOOL,
    offsetof(SscSuidRequest, has_only_default_values),
    offsetof(SscSuidRequest, only_default_values),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_suid_request__field_indices_by_name[] = {
  0,   /* field[0] = data_type */
  1,   /* field[1] = enable_updates */
  2,   /* field[2] = only_default_values */
};
static const ProtobufCIntRange ssc_suid_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 3 }
};
const ProtobufCMessageDescriptor ssc_suid_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscSuidRequest",
  "SscSuidRequest",
  "SscSuidRequest",
  "",
  sizeof(SscSuidRequest),
  3,
  ssc_suid_request__field_descriptors,
  ssc_suid_request__field_indices_by_name,
  1,  ssc_suid_request__number_ranges,
  (ProtobufCMessageInit) ssc_suid_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_suid_response__field_descriptors[2] =
{
  {
    "data_type",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(SscSuidResponse, data_type),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "uid",
    2,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(SscSuidResponse, n_uid),
    offsetof(SscSuidResponse, uid),
    &ssc_uid__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_suid_response__field_indices_by_name[] = {
  0,   /* field[0] = data_type */
  1,   /* field[1] = uid */
};
static const ProtobufCIntRange ssc_suid_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor ssc_suid_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscSuidResponse",
  "SscSuidResponse",
  "SscSuidResponse",
  "",
  sizeof(SscSuidResponse),
  2,
  ssc_suid_response__field_descriptors,
  ssc_suid_response__field_indices_by_name,
  1,  ssc_suid_response__number_ranges,
  (ProtobufCMessageInit) ssc_suid_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
