/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: ssc-common.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "ssc-common.pb-c.h"
void   ssc_uid__init
                     (SscUid         *message)
{
  static const SscUid init_value = SSC_UID__INIT;
  *message = init_value;
}
size_t ssc_uid__get_packed_size
                     (const SscUid *message)
{
  assert(message->base.descriptor == &ssc_uid__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_uid__pack
                     (const SscUid *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_uid__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_uid__pack_to_buffer
                     (const SscUid *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_uid__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscUid *
       ssc_uid__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscUid *)
     protobuf_c_message_unpack (&ssc_uid__descriptor,
                                allocator, len, data);
}
void   ssc_uid__free_unpacked
                     (SscUid *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_uid__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_client_config__init
                     (SscClientConfig         *message)
{
  static const SscClientConfig init_value = SSC_CLIENT_CONFIG__INIT;
  *message = init_value;
}
size_t ssc_client_config__get_packed_size
                     (const SscClientConfig *message)
{
  assert(message->base.descriptor == &ssc_client_config__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_client_config__pack
                     (const SscClientConfig *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_client_config__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_client_config__pack_to_buffer
                     (const SscClientConfig *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_client_config__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscClientConfig *
       ssc_client_config__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscClientConfig *)
     protobuf_c_message_unpack (&ssc_client_config__descriptor,
                                allocator, len, data);
}
void   ssc_client_config__free_unpacked
                     (SscClientConfig *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_client_config__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_client_request_body__init
                     (SscClientRequestBody         *message)
{
  static const SscClientRequestBody init_value = SSC_CLIENT_REQUEST_BODY__INIT;
  *message = init_value;
}
size_t ssc_client_request_body__get_packed_size
                     (const SscClientRequestBody *message)
{
  assert(message->base.descriptor == &ssc_client_request_body__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_client_request_body__pack
                     (const SscClientRequestBody *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_client_request_body__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_client_request_body__pack_to_buffer
                     (const SscClientRequestBody *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_client_request_body__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscClientRequestBody *
       ssc_client_request_body__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscClientRequestBody *)
     protobuf_c_message_unpack (&ssc_client_request_body__descriptor,
                                allocator, len, data);
}
void   ssc_client_request_body__free_unpacked
                     (SscClientRequestBody *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_client_request_body__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_client_request__init
                     (SscClientRequest         *message)
{
  static const SscClientRequest init_value = SSC_CLIENT_REQUEST__INIT;
  *message = init_value;
}
size_t ssc_client_request__get_packed_size
                     (const SscClientRequest *message)
{
  assert(message->base.descriptor == &ssc_client_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_client_request__pack
                     (const SscClientRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_client_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_client_request__pack_to_buffer
                     (const SscClientRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_client_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscClientRequest *
       ssc_client_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscClientRequest *)
     protobuf_c_message_unpack (&ssc_client_request__descriptor,
                                allocator, len, data);
}
void   ssc_client_request__free_unpacked
                     (SscClientRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_client_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_client_response_body__init
                     (SscClientResponseBody         *message)
{
  static const SscClientResponseBody init_value = SSC_CLIENT_RESPONSE_BODY__INIT;
  *message = init_value;
}
size_t ssc_client_response_body__get_packed_size
                     (const SscClientResponseBody *message)
{
  assert(message->base.descriptor == &ssc_client_response_body__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_client_response_body__pack
                     (const SscClientResponseBody *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_client_response_body__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_client_response_body__pack_to_buffer
                     (const SscClientResponseBody *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_client_response_body__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscClientResponseBody *
       ssc_client_response_body__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscClientResponseBody *)
     protobuf_c_message_unpack (&ssc_client_response_body__descriptor,
                                allocator, len, data);
}
void   ssc_client_response_body__free_unpacked
                     (SscClientResponseBody *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_client_response_body__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_client_response__init
                     (SscClientResponse         *message)
{
  static const SscClientResponse init_value = SSC_CLIENT_RESPONSE__INIT;
  *message = init_value;
}
size_t ssc_client_response__get_packed_size
                     (const SscClientResponse *message)
{
  assert(message->base.descriptor == &ssc_client_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_client_response__pack
                     (const SscClientResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_client_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_client_response__pack_to_buffer
                     (const SscClientResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_client_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscClientResponse *
       ssc_client_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscClientResponse *)
     protobuf_c_message_unpack (&ssc_client_response__descriptor,
                                allocator, len, data);
}
void   ssc_client_response__free_unpacked
                     (SscClientResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_client_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_attr_request__init
                     (SscAttrRequest         *message)
{
  static const SscAttrRequest init_value = SSC_ATTR_REQUEST__INIT;
  *message = init_value;
}
size_t ssc_attr_request__get_packed_size
                     (const SscAttrRequest *message)
{
  assert(message->base.descriptor == &ssc_attr_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_attr_request__pack
                     (const SscAttrRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_attr_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_attr_request__pack_to_buffer
                     (const SscAttrRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_attr_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscAttrRequest *
       ssc_attr_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscAttrRequest *)
     protobuf_c_message_unpack (&ssc_attr_request__descriptor,
                                allocator, len, data);
}
void   ssc_attr_request__free_unpacked
                     (SscAttrRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_attr_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_attr_value_array__init
                     (SscAttrValueArray         *message)
{
  static const SscAttrValueArray init_value = SSC_ATTR_VALUE_ARRAY__INIT;
  *message = init_value;
}
size_t ssc_attr_value_array__get_packed_size
                     (const SscAttrValueArray *message)
{
  assert(message->base.descriptor == &ssc_attr_value_array__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_attr_value_array__pack
                     (const SscAttrValueArray *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_attr_value_array__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_attr_value_array__pack_to_buffer
                     (const SscAttrValueArray *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_attr_value_array__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscAttrValueArray *
       ssc_attr_value_array__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscAttrValueArray *)
     protobuf_c_message_unpack (&ssc_attr_value_array__descriptor,
                                allocator, len, data);
}
void   ssc_attr_value_array__free_unpacked
                     (SscAttrValueArray *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_attr_value_array__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_attr_value__init
                     (SscAttrValue         *message)
{
  static const SscAttrValue init_value = SSC_ATTR_VALUE__INIT;
  *message = init_value;
}
size_t ssc_attr_value__get_packed_size
                     (const SscAttrValue *message)
{
  assert(message->base.descriptor == &ssc_attr_value__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_attr_value__pack
                     (const SscAttrValue *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_attr_value__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_attr_value__pack_to_buffer
                     (const SscAttrValue *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_attr_value__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscAttrValue *
       ssc_attr_value__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscAttrValue *)
     protobuf_c_message_unpack (&ssc_attr_value__descriptor,
                                allocator, len, data);
}
void   ssc_attr_value__free_unpacked
                     (SscAttrValue *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_attr_value__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_attr_array_value__init
                     (SscAttrArrayValue         *message)
{
  static const SscAttrArrayValue init_value = SSC_ATTR_ARRAY_VALUE__INIT;
  *message = init_value;
}
size_t ssc_attr_array_value__get_packed_size
                     (const SscAttrArrayValue *message)
{
  assert(message->base.descriptor == &ssc_attr_array_value__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_attr_array_value__pack
                     (const SscAttrArrayValue *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_attr_array_value__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_attr_array_value__pack_to_buffer
                     (const SscAttrArrayValue *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_attr_array_value__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscAttrArrayValue *
       ssc_attr_array_value__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscAttrArrayValue *)
     protobuf_c_message_unpack (&ssc_attr_array_value__descriptor,
                                allocator, len, data);
}
void   ssc_attr_array_value__free_unpacked
                     (SscAttrArrayValue *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_attr_array_value__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_attr__init
                     (SscAttr         *message)
{
  static const SscAttr init_value = SSC_ATTR__INIT;
  *message = init_value;
}
size_t ssc_attr__get_packed_size
                     (const SscAttr *message)
{
  assert(message->base.descriptor == &ssc_attr__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_attr__pack
                     (const SscAttr *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_attr__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_attr__pack_to_buffer
                     (const SscAttr *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_attr__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscAttr *
       ssc_attr__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscAttr *)
     protobuf_c_message_unpack (&ssc_attr__descriptor,
                                allocator, len, data);
}
void   ssc_attr__free_unpacked
                     (SscAttr *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_attr__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_attr_response__init
                     (SscAttrResponse         *message)
{
  static const SscAttrResponse init_value = SSC_ATTR_RESPONSE__INIT;
  *message = init_value;
}
size_t ssc_attr_response__get_packed_size
                     (const SscAttrResponse *message)
{
  assert(message->base.descriptor == &ssc_attr_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_attr_response__pack
                     (const SscAttrResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_attr_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_attr_response__pack_to_buffer
                     (const SscAttrResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_attr_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscAttrResponse *
       ssc_attr_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscAttrResponse *)
     protobuf_c_message_unpack (&ssc_attr_response__descriptor,
                                allocator, len, data);
}
void   ssc_attr_response__free_unpacked
                     (SscAttrResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_attr_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_enable_config_request__init
                     (SscEnableConfigRequest         *message)
{
  static const SscEnableConfigRequest init_value = SSC_ENABLE_CONFIG_REQUEST__INIT;
  *message = init_value;
}
size_t ssc_enable_config_request__get_packed_size
                     (const SscEnableConfigRequest *message)
{
  assert(message->base.descriptor == &ssc_enable_config_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_enable_config_request__pack
                     (const SscEnableConfigRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_enable_config_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_enable_config_request__pack_to_buffer
                     (const SscEnableConfigRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_enable_config_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscEnableConfigRequest *
       ssc_enable_config_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscEnableConfigRequest *)
     protobuf_c_message_unpack (&ssc_enable_config_request__descriptor,
                                allocator, len, data);
}
void   ssc_enable_config_request__free_unpacked
                     (SscEnableConfigRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_enable_config_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   ssc_config_response__init
                     (SscConfigResponse         *message)
{
  static const SscConfigResponse init_value = SSC_CONFIG_RESPONSE__INIT;
  *message = init_value;
}
size_t ssc_config_response__get_packed_size
                     (const SscConfigResponse *message)
{
  assert(message->base.descriptor == &ssc_config_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_config_response__pack
                     (const SscConfigResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_config_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_config_response__pack_to_buffer
                     (const SscConfigResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_config_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscConfigResponse *
       ssc_config_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscConfigResponse *)
     protobuf_c_message_unpack (&ssc_config_response__descriptor,
                                allocator, len, data);
}
void   ssc_config_response__free_unpacked
                     (SscConfigResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_config_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor ssc_uid__field_descriptors[2] =
{
  {
    "low",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_FIXED64,
    0,   /* quantifier_offset */
    offsetof(SscUid, low),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "high",
    2,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_FIXED64,
    0,   /* quantifier_offset */
    offsetof(SscUid, high),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_uid__field_indices_by_name[] = {
  1,   /* field[1] = high */
  0,   /* field[0] = low */
};
static const ProtobufCIntRange ssc_uid__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor ssc_uid__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscUid",
  "SscUid",
  "SscUid",
  "",
  sizeof(SscUid),
  2,
  ssc_uid__field_descriptors,
  ssc_uid__field_indices_by_name,
  1,  ssc_uid__number_ranges,
  (ProtobufCMessageInit) ssc_uid__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const int32_t ssc_client_config__processor__default_value = 1;
static const int32_t ssc_client_config__suspend_mode__default_value = 0;
static const ProtobufCFieldDescriptor ssc_client_config__field_descriptors[2] =
{
  {
    "processor",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(SscClientConfig, processor),
    NULL,
    &ssc_client_config__processor__default_value,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "suspend_mode",
    2,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(SscClientConfig, suspend_mode),
    NULL,
    &ssc_client_config__suspend_mode__default_value,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_client_config__field_indices_by_name[] = {
  0,   /* field[0] = processor */
  1,   /* field[1] = suspend_mode */
};
static const ProtobufCIntRange ssc_client_config__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor ssc_client_config__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscClientConfig",
  "SscClientConfig",
  "SscClientConfig",
  "",
  sizeof(SscClientConfig),
  2,
  ssc_client_config__field_descriptors,
  ssc_client_config__field_indices_by_name,
  1,  ssc_client_config__number_ranges,
  (ProtobufCMessageInit) ssc_client_config__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const protobuf_c_boolean ssc_client_request_body__is_passive__default_value = 0;
static const ProtobufCFieldDescriptor ssc_client_request_body__field_descriptors[3] =
{
  {
    "unknown",
    1,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_BYTES,
    offsetof(SscClientRequestBody, has_unknown),
    offsetof(SscClientRequestBody, unknown),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "msg",
    2,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_BYTES,
    offsetof(SscClientRequestBody, has_msg),
    offsetof(SscClientRequestBody, msg),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "is_passive",
    3,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_BOOL,
    offsetof(SscClientRequestBody, has_is_passive),
    offsetof(SscClientRequestBody, is_passive),
    NULL,
    &ssc_client_request_body__is_passive__default_value,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_client_request_body__field_indices_by_name[] = {
  2,   /* field[2] = is_passive */
  1,   /* field[1] = msg */
  0,   /* field[0] = unknown */
};
static const ProtobufCIntRange ssc_client_request_body__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 3 }
};
const ProtobufCMessageDescriptor ssc_client_request_body__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscClientRequestBody",
  "SscClientRequestBody",
  "SscClientRequestBody",
  "",
  sizeof(SscClientRequestBody),
  3,
  ssc_client_request_body__field_descriptors,
  ssc_client_request_body__field_indices_by_name,
  1,  ssc_client_request_body__number_ranges,
  (ProtobufCMessageInit) ssc_client_request_body__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_client_request__field_descriptors[4] =
{
  {
    "uid",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(SscClientRequest, uid),
    &ssc_uid__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "msg_id",
    2,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_FIXED32,
    0,   /* quantifier_offset */
    offsetof(SscClientRequest, msg_id),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "config",
    3,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(SscClientRequest, config),
    &ssc_client_config__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "request",
    4,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(SscClientRequest, request),
    &ssc_client_request_body__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_client_request__field_indices_by_name[] = {
  2,   /* field[2] = config */
  1,   /* field[1] = msg_id */
  3,   /* field[3] = request */
  0,   /* field[0] = uid */
};
static const ProtobufCIntRange ssc_client_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 4 }
};
const ProtobufCMessageDescriptor ssc_client_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscClientRequest",
  "SscClientRequest",
  "SscClientRequest",
  "",
  sizeof(SscClientRequest),
  4,
  ssc_client_request__field_descriptors,
  ssc_client_request__field_indices_by_name,
  1,  ssc_client_request__number_ranges,
  (ProtobufCMessageInit) ssc_client_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_client_response_body__field_descriptors[3] =
{
  {
    "msg_id",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_FIXED32,
    0,   /* quantifier_offset */
    offsetof(SscClientResponseBody, msg_id),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "timestamp",
    2,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_FIXED64,
    0,   /* quantifier_offset */
    offsetof(SscClientResponseBody, timestamp),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "msg",
    3,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_BYTES,
    0,   /* quantifier_offset */
    offsetof(SscClientResponseBody, msg),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_client_response_body__field_indices_by_name[] = {
  2,   /* field[2] = msg */
  0,   /* field[0] = msg_id */
  1,   /* field[1] = timestamp */
};
static const ProtobufCIntRange ssc_client_response_body__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 3 }
};
const ProtobufCMessageDescriptor ssc_client_response_body__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscClientResponseBody",
  "SscClientResponseBody",
  "SscClientResponseBody",
  "",
  sizeof(SscClientResponseBody),
  3,
  ssc_client_response_body__field_descriptors,
  ssc_client_response_body__field_indices_by_name,
  1,  ssc_client_response_body__number_ranges,
  (ProtobufCMessageInit) ssc_client_response_body__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_client_response__field_descriptors[2] =
{
  {
    "uid",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(SscClientResponse, uid),
    &ssc_uid__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "response",
    2,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(SscClientResponse, n_response),
    offsetof(SscClientResponse, response),
    &ssc_client_response_body__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_client_response__field_indices_by_name[] = {
  1,   /* field[1] = response */
  0,   /* field[0] = uid */
};
static const ProtobufCIntRange ssc_client_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor ssc_client_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscClientResponse",
  "SscClientResponse",
  "SscClientResponse",
  "",
  sizeof(SscClientResponse),
  2,
  ssc_client_response__field_descriptors,
  ssc_client_response__field_indices_by_name,
  1,  ssc_client_response__number_ranges,
  (ProtobufCMessageInit) ssc_client_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_attr_request__field_descriptors[1] =
{
  {
    "enable_updates",
    2,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_BOOL,
    offsetof(SscAttrRequest, has_enable_updates),
    offsetof(SscAttrRequest, enable_updates),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_attr_request__field_indices_by_name[] = {
  0,   /* field[0] = enable_updates */
};
static const ProtobufCIntRange ssc_attr_request__number_ranges[1 + 1] =
{
  { 2, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor ssc_attr_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscAttrRequest",
  "SscAttrRequest",
  "SscAttrRequest",
  "",
  sizeof(SscAttrRequest),
  1,
  ssc_attr_request__field_descriptors,
  ssc_attr_request__field_indices_by_name,
  1,  ssc_attr_request__number_ranges,
  (ProtobufCMessageInit) ssc_attr_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_attr_value_array__field_descriptors[1] =
{
  {
    "element",
    1,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(SscAttrValueArray, n_element),
    offsetof(SscAttrValueArray, element),
    &ssc_attr_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_attr_value_array__field_indices_by_name[] = {
  0,   /* field[0] = element */
};
static const ProtobufCIntRange ssc_attr_value_array__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor ssc_attr_value_array__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscAttrValueArray",
  "SscAttrValueArray",
  "SscAttrValueArray",
  "",
  sizeof(SscAttrValueArray),
  1,
  ssc_attr_value_array__field_descriptors,
  ssc_attr_value_array__field_indices_by_name,
  1,  ssc_attr_value_array__number_ranges,
  (ProtobufCMessageInit) ssc_attr_value_array__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_attr_value__field_descriptors[5] =
{
  {
    "a",
    1,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(SscAttrValue, a),
    &ssc_attr_value_array__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "s",
    2,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(SscAttrValue, s),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "f",
    3,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_FLOAT,
    offsetof(SscAttrValue, has_f),
    offsetof(SscAttrValue, f),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "i",
    4,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_FIXED64,
    offsetof(SscAttrValue, has_i),
    offsetof(SscAttrValue, i),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "b",
    5,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_BOOL,
    offsetof(SscAttrValue, has_b),
    offsetof(SscAttrValue, b),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_attr_value__field_indices_by_name[] = {
  0,   /* field[0] = a */
  4,   /* field[4] = b */
  2,   /* field[2] = f */
  3,   /* field[3] = i */
  1,   /* field[1] = s */
};
static const ProtobufCIntRange ssc_attr_value__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 5 }
};
const ProtobufCMessageDescriptor ssc_attr_value__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscAttrValue",
  "SscAttrValue",
  "SscAttrValue",
  "",
  sizeof(SscAttrValue),
  5,
  ssc_attr_value__field_descriptors,
  ssc_attr_value__field_indices_by_name,
  1,  ssc_attr_value__number_ranges,
  (ProtobufCMessageInit) ssc_attr_value__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_attr_array_value__field_descriptors[1] =
{
  {
    "v",
    1,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(SscAttrArrayValue, n_v),
    offsetof(SscAttrArrayValue, v),
    &ssc_attr_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_attr_array_value__field_indices_by_name[] = {
  0,   /* field[0] = v */
};
static const ProtobufCIntRange ssc_attr_array_value__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor ssc_attr_array_value__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscAttrArrayValue",
  "SscAttrArrayValue",
  "SscAttrArrayValue",
  "",
  sizeof(SscAttrArrayValue),
  1,
  ssc_attr_array_value__field_descriptors,
  ssc_attr_array_value__field_indices_by_name,
  1,  ssc_attr_array_value__number_ranges,
  (ProtobufCMessageInit) ssc_attr_array_value__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_attr__field_descriptors[2] =
{
  {
    "id",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(SscAttr, id),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "value_array",
    2,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(SscAttr, value_array),
    &ssc_attr_array_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_attr__field_indices_by_name[] = {
  0,   /* field[0] = id */
  1,   /* field[1] = value_array */
};
static const ProtobufCIntRange ssc_attr__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor ssc_attr__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscAttr",
  "SscAttr",
  "SscAttr",
  "",
  sizeof(SscAttr),
  2,
  ssc_attr__field_descriptors,
  ssc_attr__field_indices_by_name,
  1,  ssc_attr__number_ranges,
  (ProtobufCMessageInit) ssc_attr__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_attr_response__field_descriptors[1] =
{
  {
    "attr",
    1,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(SscAttrResponse, n_attr),
    offsetof(SscAttrResponse, attr),
    &ssc_attr__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_attr_response__field_indices_by_name[] = {
  0,   /* field[0] = attr */
};
static const ProtobufCIntRange ssc_attr_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor ssc_attr_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscAttrResponse",
  "SscAttrResponse",
  "SscAttrResponse",
  "",
  sizeof(SscAttrResponse),
  1,
  ssc_attr_response__field_descriptors,
  ssc_attr_response__field_indices_by_name,
  1,  ssc_attr_response__number_ranges,
  (ProtobufCMessageInit) ssc_attr_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_enable_config_request__field_descriptors[1] =
{
  {
    "sample_rate",
    1,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_FLOAT,
    0,   /* quantifier_offset */
    offsetof(SscEnableConfigRequest, sample_rate),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_enable_config_request__field_indices_by_name[] = {
  0,   /* field[0] = sample_rate */
};
static const ProtobufCIntRange ssc_enable_config_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor ssc_enable_config_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscEnableConfigRequest",
  "SscEnableConfigRequest",
  "SscEnableConfigRequest",
  "",
  sizeof(SscEnableConfigRequest),
  1,
  ssc_enable_config_request__field_descriptors,
  ssc_enable_config_request__field_indices_by_name,
  1,  ssc_enable_config_request__number_ranges,
  (ProtobufCMessageInit) ssc_enable_config_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor ssc_config_response__field_descriptors[2] =
{
  {
    "sample_rate",
    1,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_FLOAT,
    offsetof(SscConfigResponse, has_sample_rate),
    offsetof(SscConfigResponse, sample_rate),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "mode",
    5,
    PROTOBUF_C_LABEL_OPTIONAL,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(SscConfigResponse, mode),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_config_response__field_indices_by_name[] = {
  1,   /* field[1] = mode */
  0,   /* field[0] = sample_rate */
};
static const ProtobufCIntRange ssc_config_response__number_ranges[2 + 1] =
{
  { 1, 0 },
  { 5, 1 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor ssc_config_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscConfigResponse",
  "SscConfigResponse",
  "SscConfigResponse",
  "",
  sizeof(SscConfigResponse),
  2,
  ssc_config_response__field_descriptors,
  ssc_config_response__field_indices_by_name,
  2,  ssc_config_response__number_ranges,
  (ProtobufCMessageInit) ssc_config_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
