/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: ssc-sensor-gyroscope.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "ssc-sensor-gyroscope.pb-c.h"
void   ssc_gyroscope_response__init
                     (SscGyroscopeResponse         *message)
{
  static const SscGyroscopeResponse init_value = SSC_GYROSCOPE_RESPONSE__INIT;
  *message = init_value;
}
size_t ssc_gyroscope_response__get_packed_size
                     (const SscGyroscopeResponse *message)
{
  assert(message->base.descriptor == &ssc_gyroscope_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t ssc_gyroscope_response__pack
                     (const SscGyroscopeResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &ssc_gyroscope_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t ssc_gyroscope_response__pack_to_buffer
                     (const SscGyroscopeResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &ssc_gyroscope_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
SscGyroscopeResponse *
       ssc_gyroscope_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (SscGyroscopeResponse *)
     protobuf_c_message_unpack (&ssc_gyroscope_response__descriptor,
                                allocator, len, data);
}
void   ssc_gyroscope_response__free_unpacked
                     (SscGyroscopeResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &ssc_gyroscope_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor ssc_gyroscope_response__field_descriptors[2] =
{
  {
    "velocity",
    1,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_FLOAT,
    offsetof(SscGyroscopeResponse, n_velocity),
    offsetof(SscGyroscopeResponse, velocity),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "accuracy",
    2,
    PROTOBUF_C_LABEL_REQUIRED,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(SscGyroscopeResponse, accuracy),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned ssc_gyroscope_response__field_indices_by_name[] = {
  1,   /* field[1] = accuracy */
  0,   /* field[0] = velocity */
};
static const ProtobufCIntRange ssc_gyroscope_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor ssc_gyroscope_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "SscGyroscopeResponse",
  "SscGyroscopeResponse",
  "SscGyroscopeResponse",
  "",
  sizeof(SscGyroscopeResponse),
  2,
  ssc_gyroscope_response__field_descriptors,
  ssc_gyroscope_response__field_indices_by_name,
  1,  ssc_gyroscope_response__number_ranges,
  (ProtobufCMessageInit) ssc_gyroscope_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
